#
# spec file for package python-pytest-check-links
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Tests natually require internet
%bcond_with test
%{?sle15_python_module_pythons}
Name:           python-pytest-check-links
Version:        0.9.0
Release:        1.2
Summary:        Pytest plugin for checking links in files
License:        BSD-3-Clause
URL:            https://github.com/minrk/pytest-check-links
Source:         https://files.pythonhosted.org/packages/source/p/pytest_check_links/pytest_check_links-%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-docutils
Requires:       python-html5lib
Requires:       python-pytest >= 2.8
Requires:       python-requests
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     python-jupyter_nbconvert
Recommends:     python-jupyter_nbformat
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module html5lib}
BuildRequires:  %{python_module jupyter_nbconvert}
BuildRequires:  %{python_module jupyter_nbformat}
BuildRequires:  %{python_module pytest >= 2.8}
BuildRequires:  %{python_module requests}
%endif
%python_subpackages

%description
A pytest plugin that checks URLs for HTML-containing files.

%prep
%setup -q -n pytest_check_links-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pytest-check-links
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%pytest --check-links test/linkcheck.ipynb
%endif

%post
%python_install_alternative pytest-check-links

%postun
%python_uninstall_alternative pytest-check-links

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%python_alternative %{_bindir}/pytest-check-links
%{python_sitelib}/pytest_check_links
%{python_sitelib}/pytest_check_links-%{version}.dist-info

%changelog
* Mon Jul 24 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.0:
  * Support Python 3.8-3.12 and Handle Flaky Tests #110
  * Update ruff #106
  * Use local coverage #105
  * Switch to pytester in tests
  * Add more linting #100
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.0:
  * Update for newer requests-cache
  * Add docstring enforcement
  * Add releaser workflows
  * Include py.typed file
  * Update for pytest 7
  * Add flake8 and mypy linting
  * Apply Auto Formatting
  * Enforce labels on PRs
  * Update for Jupyter Releaser
  * Add changelog entry for 0.6.0
  * Handle ignore links for `ipynb` files
  * Drop support for Python 3.6 and add support for Python 3.10
  * Handle attachments in notebook cells
  * Fix handling of Nested RST links
  * Fix check-links-ignore example in Readme
  * Add Ability to Ignore Link Patterns
  * Update for recommended usage of CheckLinks
* Mon May 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.2:
  * Another improvement to retry logic #20
  * Clean up metadata for dist generation #19
  * Improve retry logic and add python 3 classifier #18
* Sun May  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.0:
  * Drop py27 support and add badges #15
  * Use requests(-cache) #12
  * Add checking of self- and local html anchors #10
* Mon Apr 27 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.4:
  * no changelog
* Fri Apr  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.2:
  * no upstream changelog
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Requires python-docutils
* Mon Mar 25 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Mon Mar 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.0:
  * Various examples and tests updates
* Thu Mar 21 2019 John Vandenberg <jayvdb@gmail.com>
- Fix test suite and add bcond test as the tests require internet
* Fri Apr 20 2018 toddrme2178@gmail.com
- Initial version
